@@ -541,10 +541,13 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
     """
     DS_LEN = model_options['DS_LEN']
     #### do this for dataframes ##################
-    if isinstance(keras_options["batchsize"], str):
-        batch_size = find_batch_size(DS_LEN)
-    else:
+    try:
         batch_size = keras_options["batchsize"]
+        if isinstance(keras_options["batchsize"], str):
+            batch_size = find_batch_size(DS_LEN)
+    except:
+        #### If it is not given find it here ####
+        batch_size = find_batch_size(DS_LEN)
     #########  Modify or Convert column names to fit tensorflow rules of no space in names!
     sel_preds = ["_".join(x.split(" ")) for x in list(train_small) ]
     train_small.columns = sel_preds
@@ -557,10 +560,17 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
     ### usecols is basically target in a list format. Very handy to know when target is a list.
     model_label = ''
         
-    if model_options["modeltype"] == '':
-        ### usecols is basically target in a list format. Very handy to know when target is a list.
-        modeltype, model_label, usecols = find_problem_type(train_small, target, model_options, verbose)
-    else:
+    try:
+        modeltype = model_options["modeltype"]
+        if model_options["modeltype"] == '':
+            ### usecols is basically target in a list format. Very handy to know when target is a list.
+            modeltype, model_label, usecols = find_problem_type(train_small, target, model_options, verbose)
+        else:
+            if isinstance(target, str):
+                usecols = [target]
+            else:
+                usecols = copy.deepcopy(target)
+    except:
         ### if modeltype is given, then do not find the model type using this function
         modeltype,  model_label, usecols = find_problem_type(train_small, target, model_options, verbose)
     
